/* Transfer.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from Transfer.vala, do not modify */

/*
 * This file is part of budgie-desktop
 *
 * Copyright Budgie Desktop Developers, elementary LLC
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include <glib-object.h>
#include <gio/gio.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define BLUETOOTH_OBEX_TYPE_TRANSFER (bluetooth_obex_transfer_get_type ())
#define BLUETOOTH_OBEX_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BLUETOOTH_OBEX_TYPE_TRANSFER, BluetoothObexTransfer))
#define BLUETOOTH_OBEX_IS_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BLUETOOTH_OBEX_TYPE_TRANSFER))
#define BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BLUETOOTH_OBEX_TYPE_TRANSFER, BluetoothObexTransferIface))

typedef struct _BluetoothObexTransfer BluetoothObexTransfer;
typedef struct _BluetoothObexTransferIface BluetoothObexTransferIface;

#define BLUETOOTH_OBEX_TYPE_TRANSFER_PROXY (bluetooth_obex_transfer_proxy_get_type ())
typedef GDBusProxy BluetoothObexTransferProxy;
typedef GDBusProxyClass BluetoothObexTransferProxyClass;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _BluetoothObexTransferIface {
	GTypeInterface parent_iface;
	void (*cancel) (BluetoothObexTransfer* self, GError** error);
	void (*resume) (BluetoothObexTransfer* self, GError** error);
	void (*suspend) (BluetoothObexTransfer* self, GError** error);
	gchar* (*get_status) (BluetoothObexTransfer* self);
	char* (*get_session) (BluetoothObexTransfer* self);
	gchar* (*get_name) (BluetoothObexTransfer* self);
	gchar* (*get_Type) (BluetoothObexTransfer* self);
	guint64 (*get_time) (BluetoothObexTransfer* self);
	guint64 (*get_size) (BluetoothObexTransfer* self);
	guint64 (*get_transferred) (BluetoothObexTransfer* self);
	gchar* (*get_filename) (BluetoothObexTransfer* self);
};

VALA_EXTERN GType bluetooth_obex_transfer_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint bluetooth_obex_transfer_register_object (void* object,
                                               GDBusConnection* connection,
                                               const gchar* path,
                                               GError** error);
VALA_EXTERN GType bluetooth_obex_transfer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BluetoothObexTransfer, g_object_unref)
VALA_EXTERN void bluetooth_obex_transfer_cancel (BluetoothObexTransfer* self,
                                     GError** error);
VALA_EXTERN void bluetooth_obex_transfer_resume (BluetoothObexTransfer* self,
                                     GError** error);
VALA_EXTERN void bluetooth_obex_transfer_suspend (BluetoothObexTransfer* self,
                                      GError** error);
VALA_EXTERN gchar* bluetooth_obex_transfer_get_status (BluetoothObexTransfer* self);
VALA_EXTERN char* bluetooth_obex_transfer_get_session (BluetoothObexTransfer* self);
VALA_EXTERN gchar* bluetooth_obex_transfer_get_name (BluetoothObexTransfer* self);
VALA_EXTERN gchar* bluetooth_obex_transfer_get_Type (BluetoothObexTransfer* self);
VALA_EXTERN guint64 bluetooth_obex_transfer_get_time (BluetoothObexTransfer* self);
VALA_EXTERN guint64 bluetooth_obex_transfer_get_size (BluetoothObexTransfer* self);
VALA_EXTERN guint64 bluetooth_obex_transfer_get_transferred (BluetoothObexTransfer* self);
VALA_EXTERN gchar* bluetooth_obex_transfer_get_filename (BluetoothObexTransfer* self);
static GType bluetooth_obex_transfer_get_type_once (void);
static void bluetooth_obex_transfer_proxy_g_signal (GDBusProxy* proxy,
                                             const gchar* sender_name,
                                             const gchar* signal_name,
                                             GVariant* parameters);
static void bluetooth_obex_transfer_proxy_cancel (BluetoothObexTransfer* self,
                                           GError** error);
static void bluetooth_obex_transfer_proxy_resume (BluetoothObexTransfer* self,
                                           GError** error);
static void bluetooth_obex_transfer_proxy_suspend (BluetoothObexTransfer* self,
                                            GError** error);
static gchar* bluetooth_obex_transfer_dbus_proxy_get_status (BluetoothObexTransfer* self);
static char* bluetooth_obex_transfer_dbus_proxy_get_session (BluetoothObexTransfer* self);
static gchar* bluetooth_obex_transfer_dbus_proxy_get_name (BluetoothObexTransfer* self);
static gchar* bluetooth_obex_transfer_dbus_proxy_get_Type (BluetoothObexTransfer* self);
static guint64 bluetooth_obex_transfer_dbus_proxy_get_time (BluetoothObexTransfer* self);
static guint64 bluetooth_obex_transfer_dbus_proxy_get_size (BluetoothObexTransfer* self);
static guint64 bluetooth_obex_transfer_dbus_proxy_get_transferred (BluetoothObexTransfer* self);
static gchar* bluetooth_obex_transfer_dbus_proxy_get_filename (BluetoothObexTransfer* self);
static void bluetooth_obex_transfer_proxy_bluetooth_obex_transfer_interface_init (BluetoothObexTransferIface* iface);
static void _dbus_bluetooth_obex_transfer_cancel (BluetoothObexTransfer* self,
                                           GVariant* _parameters_,
                                           GDBusMethodInvocation* invocation);
static void _dbus_bluetooth_obex_transfer_resume (BluetoothObexTransfer* self,
                                           GVariant* _parameters_,
                                           GDBusMethodInvocation* invocation);
static void _dbus_bluetooth_obex_transfer_suspend (BluetoothObexTransfer* self,
                                            GVariant* _parameters_,
                                            GDBusMethodInvocation* invocation);
static void bluetooth_obex_transfer_dbus_interface_method_call (GDBusConnection* connection,
                                                         const gchar* sender,
                                                         const gchar* object_path,
                                                         const gchar* interface_name,
                                                         const gchar* method_name,
                                                         GVariant* parameters,
                                                         GDBusMethodInvocation* invocation,
                                                         gpointer user_data);
static GVariant* bluetooth_obex_transfer_dbus_interface_get_property (GDBusConnection* connection,
                                                               const gchar* sender,
                                                               const gchar* object_path,
                                                               const gchar* interface_name,
                                                               const gchar* property_name,
                                                               GError** error,
                                                               gpointer user_data);
static GVariant* _dbus_bluetooth_obex_transfer_get_status (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_session (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_name (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_Type (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_time (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_size (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_transferred (BluetoothObexTransfer* self);
static GVariant* _dbus_bluetooth_obex_transfer_get_filename (BluetoothObexTransfer* self);
static gboolean bluetooth_obex_transfer_dbus_interface_set_property (GDBusConnection* connection,
                                                              const gchar* sender,
                                                              const gchar* object_path,
                                                              const gchar* interface_name,
                                                              const gchar* property_name,
                                                              GVariant* value,
                                                              GError** error,
                                                              gpointer user_data);
static void _bluetooth_obex_transfer_unregister_object (gpointer user_data);

static const GDBusArgInfo * const _bluetooth_obex_transfer_dbus_arg_info_cancel_in[] = {NULL};
static const GDBusArgInfo * const _bluetooth_obex_transfer_dbus_arg_info_cancel_out[] = {NULL};
static const GDBusMethodInfo _bluetooth_obex_transfer_dbus_method_info_cancel = {-1, "Cancel", (GDBusArgInfo **) (&_bluetooth_obex_transfer_dbus_arg_info_cancel_in), (GDBusArgInfo **) (&_bluetooth_obex_transfer_dbus_arg_info_cancel_out), NULL};
static const GDBusArgInfo * const _bluetooth_obex_transfer_dbus_arg_info_resume_in[] = {NULL};
static const GDBusArgInfo * const _bluetooth_obex_transfer_dbus_arg_info_resume_out[] = {NULL};
static const GDBusMethodInfo _bluetooth_obex_transfer_dbus_method_info_resume = {-1, "Resume", (GDBusArgInfo **) (&_bluetooth_obex_transfer_dbus_arg_info_resume_in), (GDBusArgInfo **) (&_bluetooth_obex_transfer_dbus_arg_info_resume_out), NULL};
static const GDBusArgInfo * const _bluetooth_obex_transfer_dbus_arg_info_suspend_in[] = {NULL};
static const GDBusArgInfo * const _bluetooth_obex_transfer_dbus_arg_info_suspend_out[] = {NULL};
static const GDBusMethodInfo _bluetooth_obex_transfer_dbus_method_info_suspend = {-1, "Suspend", (GDBusArgInfo **) (&_bluetooth_obex_transfer_dbus_arg_info_suspend_in), (GDBusArgInfo **) (&_bluetooth_obex_transfer_dbus_arg_info_suspend_out), NULL};
static const GDBusMethodInfo * const _bluetooth_obex_transfer_dbus_method_info[] = {&_bluetooth_obex_transfer_dbus_method_info_cancel, &_bluetooth_obex_transfer_dbus_method_info_resume, &_bluetooth_obex_transfer_dbus_method_info_suspend, NULL};
static const GDBusSignalInfo * const _bluetooth_obex_transfer_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_status = {-1, "Status", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_session = {-1, "Session", "o", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_name = {-1, "Name", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_Type = {-1, "Type", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_time = {-1, "Time", "t", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_size = {-1, "Size", "t", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_transferred = {-1, "Transferred", "t", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _bluetooth_obex_transfer_dbus_property_info_filename = {-1, "Filename", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo * const _bluetooth_obex_transfer_dbus_property_info[] = {&_bluetooth_obex_transfer_dbus_property_info_status, &_bluetooth_obex_transfer_dbus_property_info_session, &_bluetooth_obex_transfer_dbus_property_info_name, &_bluetooth_obex_transfer_dbus_property_info_Type, &_bluetooth_obex_transfer_dbus_property_info_time, &_bluetooth_obex_transfer_dbus_property_info_size, &_bluetooth_obex_transfer_dbus_property_info_transferred, &_bluetooth_obex_transfer_dbus_property_info_filename, NULL};
static const GDBusInterfaceInfo _bluetooth_obex_transfer_dbus_interface_info = {-1, "org.bluez.obex.Transfer1", (GDBusMethodInfo **) (&_bluetooth_obex_transfer_dbus_method_info), (GDBusSignalInfo **) (&_bluetooth_obex_transfer_dbus_signal_info), (GDBusPropertyInfo **) (&_bluetooth_obex_transfer_dbus_property_info), NULL};
static const GDBusInterfaceVTable _bluetooth_obex_transfer_dbus_interface_vtable = {bluetooth_obex_transfer_dbus_interface_method_call, bluetooth_obex_transfer_dbus_interface_get_property, bluetooth_obex_transfer_dbus_interface_set_property};

void
bluetooth_obex_transfer_cancel (BluetoothObexTransfer* self,
                                GError** error)
{
	BluetoothObexTransferIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->cancel) {
		_iface_->cancel (self, error);
	}
}

void
bluetooth_obex_transfer_resume (BluetoothObexTransfer* self,
                                GError** error)
{
	BluetoothObexTransferIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->resume) {
		_iface_->resume (self, error);
	}
}

void
bluetooth_obex_transfer_suspend (BluetoothObexTransfer* self,
                                 GError** error)
{
	BluetoothObexTransferIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->suspend) {
		_iface_->suspend (self, error);
	}
}

gchar*
bluetooth_obex_transfer_get_status (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_status) {
		return _iface_->get_status (self);
	}
	return NULL;
}

char*
bluetooth_obex_transfer_get_session (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_session) {
		return _iface_->get_session (self);
	}
	return NULL;
}

gchar*
bluetooth_obex_transfer_get_name (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_name) {
		return _iface_->get_name (self);
	}
	return NULL;
}

gchar*
bluetooth_obex_transfer_get_Type (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_Type) {
		return _iface_->get_Type (self);
	}
	return NULL;
}

guint64
bluetooth_obex_transfer_get_time (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, 0ULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_time) {
		return _iface_->get_time (self);
	}
	return 0ULL;
}

guint64
bluetooth_obex_transfer_get_size (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, 0ULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_size) {
		return _iface_->get_size (self);
	}
	return 0ULL;
}

guint64
bluetooth_obex_transfer_get_transferred (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, 0ULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_transferred) {
		return _iface_->get_transferred (self);
	}
	return 0ULL;
}

gchar*
bluetooth_obex_transfer_get_filename (BluetoothObexTransfer* self)
{
	BluetoothObexTransferIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = BLUETOOTH_OBEX_TRANSFER_GET_INTERFACE (self);
	if (_iface_->get_filename) {
		return _iface_->get_filename (self);
	}
	return NULL;
}

static void
bluetooth_obex_transfer_default_init (BluetoothObexTransferIface * iface,
                                      gpointer iface_data)
{
}

 G_GNUC_NO_INLINE static GType
bluetooth_obex_transfer_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BluetoothObexTransferIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) bluetooth_obex_transfer_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType bluetooth_obex_transfer_type_id;
	bluetooth_obex_transfer_type_id = g_type_register_static (G_TYPE_INTERFACE, "BluetoothObexTransfer", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (bluetooth_obex_transfer_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (bluetooth_obex_transfer_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) bluetooth_obex_transfer_proxy_get_type);
	g_type_set_qdata (bluetooth_obex_transfer_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.bluez.obex.Transfer1");
	g_type_set_qdata (bluetooth_obex_transfer_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_bluetooth_obex_transfer_dbus_interface_info));
	g_type_set_qdata (bluetooth_obex_transfer_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) bluetooth_obex_transfer_register_object);
	return bluetooth_obex_transfer_type_id;
}

GType
bluetooth_obex_transfer_get_type (void)
{
	static volatile gsize bluetooth_obex_transfer_type_id__once = 0;
	if (g_once_init_enter (&bluetooth_obex_transfer_type_id__once)) {
		GType bluetooth_obex_transfer_type_id;
		bluetooth_obex_transfer_type_id = bluetooth_obex_transfer_get_type_once ();
		g_once_init_leave (&bluetooth_obex_transfer_type_id__once, bluetooth_obex_transfer_type_id);
	}
	return bluetooth_obex_transfer_type_id__once;
}

G_DEFINE_TYPE_EXTENDED (BluetoothObexTransferProxy, bluetooth_obex_transfer_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BLUETOOTH_OBEX_TYPE_TRANSFER, bluetooth_obex_transfer_proxy_bluetooth_obex_transfer_interface_init) )
static void
bluetooth_obex_transfer_proxy_class_init (BluetoothObexTransferProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = bluetooth_obex_transfer_proxy_g_signal;
}

static void
bluetooth_obex_transfer_proxy_g_signal (GDBusProxy* proxy,
                                        const gchar* sender_name,
                                        const gchar* signal_name,
                                        GVariant* parameters)
{
}

static void
bluetooth_obex_transfer_proxy_init (BluetoothObexTransferProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_bluetooth_obex_transfer_dbus_interface_info));
}

static void
bluetooth_obex_transfer_proxy_cancel (BluetoothObexTransfer* self,
                                      GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.obex.Transfer1", "Cancel");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
bluetooth_obex_transfer_proxy_resume (BluetoothObexTransfer* self,
                                      GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.obex.Transfer1", "Resume");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
bluetooth_obex_transfer_proxy_suspend (BluetoothObexTransfer* self,
                                       GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.bluez.obex.Transfer1", "Suspend");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static gchar*
bluetooth_obex_transfer_dbus_proxy_get_status (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Status");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Status"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static char*
bluetooth_obex_transfer_dbus_proxy_get_session (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	char* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Session");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Session"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
bluetooth_obex_transfer_dbus_proxy_get_name (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Name");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Name"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
bluetooth_obex_transfer_dbus_proxy_get_Type (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Type");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Type"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static guint64
bluetooth_obex_transfer_dbus_proxy_get_time (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	guint64 _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Time");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Time"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			guint64 _tmp43_ = 0ULL;
			return _tmp43_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_uint64 (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static guint64
bluetooth_obex_transfer_dbus_proxy_get_size (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	guint64 _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Size");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Size"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			guint64 _tmp44_ = 0ULL;
			return _tmp44_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_uint64 (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static guint64
bluetooth_obex_transfer_dbus_proxy_get_transferred (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	guint64 _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Transferred");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Transferred"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			guint64 _tmp45_ = 0ULL;
			return _tmp45_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_uint64 (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
bluetooth_obex_transfer_dbus_proxy_get_filename (BluetoothObexTransfer* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Filename");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.bluez.obex.Transfer1"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Filename"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
bluetooth_obex_transfer_proxy_bluetooth_obex_transfer_interface_init (BluetoothObexTransferIface* iface)
{
	iface->cancel = bluetooth_obex_transfer_proxy_cancel;
	iface->resume = bluetooth_obex_transfer_proxy_resume;
	iface->suspend = bluetooth_obex_transfer_proxy_suspend;
	iface->get_status = bluetooth_obex_transfer_dbus_proxy_get_status;
	iface->get_session = bluetooth_obex_transfer_dbus_proxy_get_session;
	iface->get_name = bluetooth_obex_transfer_dbus_proxy_get_name;
	iface->get_Type = bluetooth_obex_transfer_dbus_proxy_get_Type;
	iface->get_time = bluetooth_obex_transfer_dbus_proxy_get_time;
	iface->get_size = bluetooth_obex_transfer_dbus_proxy_get_size;
	iface->get_transferred = bluetooth_obex_transfer_dbus_proxy_get_transferred;
	iface->get_filename = bluetooth_obex_transfer_dbus_proxy_get_filename;
}

static void
_dbus_bluetooth_obex_transfer_cancel (BluetoothObexTransfer* self,
                                      GVariant* _parameters_,
                                      GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	bluetooth_obex_transfer_cancel (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_bluetooth_obex_transfer_resume (BluetoothObexTransfer* self,
                                      GVariant* _parameters_,
                                      GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	bluetooth_obex_transfer_resume (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_bluetooth_obex_transfer_suspend (BluetoothObexTransfer* self,
                                       GVariant* _parameters_,
                                       GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	bluetooth_obex_transfer_suspend (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
bluetooth_obex_transfer_dbus_interface_method_call (GDBusConnection* connection,
                                                    const gchar* sender,
                                                    const gchar* object_path,
                                                    const gchar* interface_name,
                                                    const gchar* method_name,
                                                    GVariant* parameters,
                                                    GDBusMethodInvocation* invocation,
                                                    gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Cancel") == 0) {
		_dbus_bluetooth_obex_transfer_cancel (object, parameters, invocation);
	} else if (strcmp (method_name, "Resume") == 0) {
		_dbus_bluetooth_obex_transfer_resume (object, parameters, invocation);
	} else if (strcmp (method_name, "Suspend") == 0) {
		_dbus_bluetooth_obex_transfer_suspend (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_status (BluetoothObexTransfer* self)
{
	gchar* result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_status (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_session (BluetoothObexTransfer* self)
{
	char* result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_session (self);
	_reply = g_variant_new_object_path (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_name (BluetoothObexTransfer* self)
{
	gchar* result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_name (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_Type (BluetoothObexTransfer* self)
{
	gchar* result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_Type (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_time (BluetoothObexTransfer* self)
{
	guint64 result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_time (self);
	_reply = g_variant_new_uint64 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_size (BluetoothObexTransfer* self)
{
	guint64 result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_size (self);
	_reply = g_variant_new_uint64 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_transferred (BluetoothObexTransfer* self)
{
	guint64 result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_transferred (self);
	_reply = g_variant_new_uint64 (result);
	return _reply;
}

static GVariant*
_dbus_bluetooth_obex_transfer_get_filename (BluetoothObexTransfer* self)
{
	gchar* result;
	GVariant* _reply;
	result = bluetooth_obex_transfer_get_filename (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
bluetooth_obex_transfer_dbus_interface_get_property (GDBusConnection* connection,
                                                     const gchar* sender,
                                                     const gchar* object_path,
                                                     const gchar* interface_name,
                                                     const gchar* property_name,
                                                     GError** error,
                                                     gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "Status") == 0) {
		return _dbus_bluetooth_obex_transfer_get_status (object);
	} else if (strcmp (property_name, "Session") == 0) {
		return _dbus_bluetooth_obex_transfer_get_session (object);
	} else if (strcmp (property_name, "Name") == 0) {
		return _dbus_bluetooth_obex_transfer_get_name (object);
	} else if (strcmp (property_name, "Type") == 0) {
		return _dbus_bluetooth_obex_transfer_get_Type (object);
	} else if (strcmp (property_name, "Time") == 0) {
		return _dbus_bluetooth_obex_transfer_get_time (object);
	} else if (strcmp (property_name, "Size") == 0) {
		return _dbus_bluetooth_obex_transfer_get_size (object);
	} else if (strcmp (property_name, "Transferred") == 0) {
		return _dbus_bluetooth_obex_transfer_get_transferred (object);
	} else if (strcmp (property_name, "Filename") == 0) {
		return _dbus_bluetooth_obex_transfer_get_filename (object);
	}
	return NULL;
}

static gboolean
bluetooth_obex_transfer_dbus_interface_set_property (GDBusConnection* connection,
                                                     const gchar* sender,
                                                     const gchar* object_path,
                                                     const gchar* interface_name,
                                                     const gchar* property_name,
                                                     GVariant* value,
                                                     GError** error,
                                                     gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}

guint
bluetooth_obex_transfer_register_object (gpointer object,
                                         GDBusConnection* connection,
                                         const gchar* path,
                                         GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_bluetooth_obex_transfer_dbus_interface_info), &_bluetooth_obex_transfer_dbus_interface_vtable, data, _bluetooth_obex_transfer_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_bluetooth_obex_transfer_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

